.. _spider_verbraucherrecht.at:

verbraucherrecht.at
-------------------
Newest articles from `Verbraucherrecht <https://verbraucherrecht.at>`_.

Configuration
~~~~~~~~~~~~~
Add ``verbraucherrecht.at`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     verbraucherrecht.at

